@@ -10,7 +10,7 @@ import logging
 import sys
 
 from jira_commands.cli.common import baseCLIParser, parseTicketCLI, ticketCreationParser
-from jira_commands.jira import JiraTool, loadJiraSettings, makeIssueData
+from jira_commands.jira import JiraTool, load_jira_settings, make_issue_data
 
 
 def parseTicketAssignCLI():
@@ -198,13 +198,13 @@ def assignTicket():
     cli = parseTicketAssignCLI()
     logging.debug(f"cli: {cli}")
 
-    settings = loadJiraSettings(path=cli.settings_file, cli=cli)
+    settings = load_jira_settings(path=cli.settings_file, cli=cli)
 
     jira = JiraTool(settings=settings)
     if cli.assignee.lower() == "none":
-        jira.unassignTicket(ticket=cli.ticket)
+        jira.unassign_ticket(ticket=cli.ticket)
     else:
-        jira.assignTicket(ticket=cli.ticket, assignee=cli.assignee)
+        jira.assign_ticket(ticket=cli.ticket, assignee=cli.assignee)
 
 
 def commentOnTicket():
@@ -214,10 +214,10 @@ def commentOnTicket():
     cli = parseTicketCommentCLI()
     logging.debug(f"cli: {cli}")
 
-    settings = loadJiraSettings(path=cli.settings_file, cli=cli)
+    settings = load_jira_settings(path=cli.settings_file, cli=cli)
 
     jira = JiraTool(settings=settings)
-    jira.addComment(ticket=cli.ticket, comment=cli.comment)
+    jira.add_comment(ticket=cli.ticket, comment=cli.comment)
 
 
 def closeTicket():
@@ -227,10 +227,10 @@ def closeTicket():
     cli = parseTicketCommentCLI()
     logging.debug(f"cli: {cli}")
 
-    settings = loadJiraSettings(path=cli.settings_file, cli=cli)
+    settings = load_jira_settings(path=cli.settings_file, cli=cli)
 
     jira = JiraTool(settings=settings)
-    jira.transitionTicket(ticket=cli.ticket, state="Done", comment=cli.comment)
+    jira.transition_ticket(ticket=cli.ticket, state="Done", comment=cli.comment)
 
 
 def createTicket():
@@ -240,14 +240,14 @@ def createTicket():
     cli = parseCreateTicketCLI()
     logging.debug(f"cli: {cli}")
 
-    settings = loadJiraSettings(path=cli.settings_file, cli=cli)
-    issue_data = makeIssueData(cli=cli)
+    settings = load_jira_settings(path=cli.settings_file, cli=cli)
+    issue_data = make_issue_data(cli=cli)
 
     jira = JiraTool(settings=settings)
     if cli.issue_type == "Sub-task":
-        results = jira.createSubtask(issue_data=issue_data, parent=cli.parent)
+        results = jira.create_subtask(issue_data=issue_data, parent=cli.parent)
     else:
-        results = jira.createTicket(
+        results = jira.create_ticket(
             issue_data=issue_data, strict=False, priority=cli.priority
         )
     print(results)
@@ -267,7 +267,7 @@ def getLinkTypes():
     logging.basicConfig(level=loglevel, format=logFormat)
     logging.debug("Set log level to %s", cli.log_level.upper())
 
-    settings = loadJiraSettings(path=cli.settings_file, cli=cli)
+    settings = load_jira_settings(path=cli.settings_file, cli=cli)
 
     jira = JiraTool(settings=settings)
 
@@ -288,10 +288,10 @@ def linkTickets():
     cli = parseTicketLinkCLI()
     logging.debug(f"cli: {cli}")
 
-    settings = loadJiraSettings(path=cli.settings_file, cli=cli)
+    settings = load_jira_settings(path=cli.settings_file, cli=cli)
 
     jira = JiraTool(settings=settings)
-    results = jira.linkIssues(
+    results = jira.link_issues(
         source=cli.ticket, target=cli.target, link_type=cli.link_type
     )
     logging.debug(results)
@@ -319,10 +319,10 @@ def getPriorities():
     logging.basicConfig(level=loglevel, format=logFormat)
     logging.debug("Set log level to %s", cli.log_level.upper())
 
-    settings = loadJiraSettings(path=cli.settings_file, cli=cli)
+    settings = load_jira_settings(path=cli.settings_file, cli=cli)
 
     jira = JiraTool(settings=settings)
-    priority_data = jira.getPriorityDict()
+    priority_data = jira.get_priority_dict()
 
     if cli.json:
         print(json.dumps({"priorities": priority_data}, indent=2))
@@ -337,10 +337,10 @@ def getTransitions():
     cli = parseGetTransitionsCLI()
     logging.debug(f"cli: {cli}")
 
-    settings = loadJiraSettings(path=cli.settings_file, cli=cli)
+    settings = load_jira_settings(path=cli.settings_file, cli=cli)
 
     jira = JiraTool(settings=settings)
-    print(jira.ticketTransitions(ticket=cli.ticket))
+    print(jira.ticket_transitions(ticket=cli.ticket))
 
 
 def transitionTo():
@@ -350,10 +350,10 @@ def transitionTo():
     cli = parseTransitionToCLI()
     logging.debug(f"cli: {cli}")
 
-    settings = loadJiraSettings(path=cli.settings_file, cli=cli)
+    settings = load_jira_settings(path=cli.settings_file, cli=cli)
 
     jira = JiraTool(settings=settings)
-    print(jira.transitionTicket(ticket=cli.ticket, state=cli.transition_to))
+    print(jira.transition_ticket(ticket=cli.ticket, state=cli.transition_to))
 
 
 if __name__ == "__main__":
