@@ -1,4 +1,3 @@
-#!/usr/bin/env python3
 #
 # Utility functions
 #
@@ -10,6 +9,9 @@
 def dump_object(obj):
     """
     Dump an object for debugging
+
+    Args:
+        obj: a python object to dump
     """
     for attr in dir(obj):
         print("obj.%s = %r" % (attr, getattr(obj, attr)))
